%define ALD_Ver		1.2.1

Name:         e2fsprogs

License:      GPLv2
Summary:      Utilities for managing ext2/ext3/ext4 filesystems
Group:        System Environment/Base
Version:      1.42.8
Release:      3
Url: http://e2fsprogs.sourceforge.net/

Source: %{name}-%{version}.tar.xz
Source1: CROSS.sh

%define DestDir		/fs

# -----------------------------------------------------
%if %{_target_cpu} == %{_build_cpu}
%define _CROSS 0
%define BUILD_LOCAL_CROSS 0
%else
# rpm --target=x86_64/armv6l/win32 -ba xxxxx.spec
%define _CROSS 1
%define BUILD_LOCAL_CROSS 1
%endif

%define TO_ARCH %{_target_cpu}

%if %{_target_cpu} == "armv6l"
%define ARM_ARCH armv6zk
%define ARM_FPU  -mfpu=vfp -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%if %{_target_cpu} == "armv7l"
%define ARM_ARCH armv7-a
%define ARM_FPU  -mfpu=vfpv3-d16 -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%define BUILD_TAR 1
#------------------ CROSS DIR --------------------
%if %{_CROSS}

%if %{_os} == "mingw"
%define target %{_arch}-%{_vendor}-%{_os}%{__isa_bits}
%else  #win32 || win64
%define target %{_arch}-%{_os}%{_gnu}
%endif
%define target_  %{target}-

%define crossdir	/cross
%if %{_arch} == "arm"
%define csysdir		%{crossdir}/%{ARM_ARCH}
%else
%define csysdir		%{crossdir}/%{_target_cpu}
%endif
%define csysbindir	%{csysdir}/bin

%define __os_install_post %{nil}

%define cross_bindir	%{csysdir}%{_bindir}
%define cross_sbindir	%{csysdir}%{_sbindir}
%define cross_libdir	%{csysdir}%{_libdir}
%define cross_includedir %{csysdir}%{_includedir}
%define cross_datadir	%{csysdir}%{_datadir}
%define cross_infodir	%{csysdir}%{_infodir}
%define cross_mandir	%{csysdir}%{_mandir}
%define cross_defaultdocdir %{csysdir}%{_defaultdocdir}
%define cross_docdir	%{cross_defaultdocdir}/%{name}

%define CrossDestDir	/Cross

%define _srcrpmdir	%{_topdir}/SRPMS/tmp

%else  #_CROSS

%define csysbindir	%{_prefix}/bin
%define CrossDestDir	%{nil}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}

%define target_  %{nil}
%define target %{_build}

%endif # !_CROSS

%define docdir %{_defaultdocdir}/%{name}

# ------------------- description ------------------------------------
%description
The e2fsprogs package contains a number of utilities for creating,
checking, modifying, and correcting any inconsistencies in ext2, ext3,
and ext4 filesystems.  E2fsprogs contains e2fsck (used to repair
filesystem inconsistencies after an unclean shutdown), mke2fs (used to
initialize a partition to contain an empty ext2 filesystem), debugfs
(used to examine the internal structure of a filesystem, to manually
repair a corrupted filesystem or to create test cases for e2fsck),
tune2fs (used to modify filesystem parameters), resize2fs to grow and
shrink unmounted ext2 filesystems, and most of the other core ext2fs
filesystem utilities.

You should install the e2fsprogs package if you are using any ext2,
ext3, or ext4 filesystems (if you're not sure, you probably should
install this package).  You may also need to install it (even if you
don't use ext2/ext3/ext4) for the libuuid and libblkid libraries and
fsck tool that are included here.
#-------------------------------
%package devel
Summary:      Libraries for the C compiler
Group:        Development/Libraries
%description devel
These libraries are needed to compile C code.
# --------------------------------------
%package devel-man
Summary:      %{name} devel man for Libraries
Group:        Development/Libraries
%description devel-man
%{name} devel man for Libraries
# --------------------------------------
%package staticlib
Summary:      %{name} static Libraries
Group:        Development/Libraries
%description staticlib
%{name} static Libraries
# --------------------------------------
%package info
Summary:      Info for %{name}
Group:        Documentation
%description info
Info for %{name}
# --------------------------------------
%package uuidd
Summary:      helper daemon to guarantee uniqueness of time-based UUIDs
Group:        System Environment/Daemons
%description uuidd
The uuidd package contains a userspace daemon (uuidd) which guarantees
uniqueness of time-based UUID generation even at very high rates on
SMP systems.

#-------------------------------
%package %{TO_ARCH}
Summary:      %{name} Cross-%{TO_ARCH} Libraries
Group:        Development/Libraries
%description %{TO_ARCH}
%{name} Cross-%{TO_ARCH} Libraries
# --------------------------------------
%package %{TO_ARCH}-staticlib
Summary:      %{name} Cross-%{TO_ARCH} static Libraries
Group:        Development/Libraries
%description %{TO_ARCH}-staticlib
%{name} Cross-%{TO_ARCH} static Libraries

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{name}-%{version}
#sed -i s:"    root_bindir=\$bindir":"    root_bindir=/bin": configure
#sed -i s:"    root_sbindir=\$sbindir":"    root_sbindir=/sbin": configure
#sed -i s:"    root_libdir=\$libdir":"    root_libdir=/%{_lib}": configure

# ------------------- Build ------------------------------------------
%Build
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

%if %{_arch} == "i386"
OPTFLAGS="-O2 -march=i486 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-O2 -fno-asynchronous-unwind-tables"
%endif
%if %{_arch} == "arm"
OPTFLAGS="-O2 -march=%{ARM_ARCH} %{ARM_FPU} -munaligned-access"
%endif

%if %{_os} == "mingw"
CFLAGS="$OPTFLAGS"
LDFLAGS=" "
%else
CFLAGS="$OPTFLAGS"
GCC_VER_STR=`%{target_}gcc -dumpversion`
LDFLAGS=`case $GCC_VER_STR in \
 4.[56789].*) echo -static-libgcc ;; \
 esac`
LDFLAGS="$LDFLAGS -Wl,--gc-sections"
%endif

%configure \
%if %{_CROSS}
	--build=i386-pc-linux-gnu \
	--host=%{target} \
%endif
	--with-root-prefix="" \
	--enable-verbose-makecmds \
	--enable-elf-shlibs \
	--disable-debugfs \
	--disable-e2initrd-helper \
	--disable-testio-debug \
	--disable-nls \
	--disable-rpath \
	--enable-symlink-build \
	--enable-symlink-install \
	&>FConfigure_log.txt

make &>FMake_log.txt

# ------------------- Install ----------------------------------------
%Install
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}
mkdir -p $RPM_BUILD_ROOT/var/lib/libuuid

make install install-libs DESTDIR="$RPM_BUILD_ROOT" \
	root_sbindir=/sbin root_libdir=/%{_lib} \
	&>FInstall_log.txt

rm -rf $RPM_BUILD_ROOT%{_infodir}/dir
cp COPYING README $RPM_BUILD_ROOT%{docdir}/

%if %{_CROSS}
TARGET_PRFIX=%{_prefix}
TARGET_CROSS_PRFIX=%{csysdir}
TARGET_NAME=%{target}
MKCROSSDIR=%{BUILD_LOCAL_CROSS}
export TARGET_PRFIX TARGET_CROSS_PRFIX TARGET_NAME MKCROSSDIR
%SOURCE1
%if %{BUILD_LOCAL_CROSS}
rm -r $RPM_BUILD_ROOT%{csysdir}/etc
rm -r $RPM_BUILD_ROOT%{csysdir}/sbin
rm -r $RPM_BUILD_ROOT%{csysdir}/var
rm -r $RPM_BUILD_ROOT%{cross_bindir}
rm -r $RPM_BUILD_ROOT%{cross_sbindir}
rm -r $RPM_BUILD_ROOT%{cross_datadir}/et
rm -r $RPM_BUILD_ROOT%{cross_datadir}/ss
rm -r $RPM_BUILD_ROOT%{cross_mandir}
rm -r $RPM_BUILD_ROOT%{cross_infodir}
pushd $RPM_BUILD_ROOT%{cross_libdir}
  rm libblkid.so libcom_err.so libe2p.so libext2fs.so libss.so libuuid.so
  ln -s ../../lib/libblkid.so.1 libblkid.so
  ln -s ../../lib/libcom_err.so.2 libcom_err.so
  ln -s ../../lib/libe2p.so.2 libe2p.so
  ln -s ../../lib/libext2fs.so.2 libext2fs.so
  ln -s ../../lib/libss.so.2 libss.so
  ln -s ../../lib/libuuid.so.1 libuuid.so
popd
%endif #BUILD_LOCAL_CROSS
%endif #_CROSS


%if !%{_CROSS}
if test -f /opt/aldccp/bin/packages_idx; then
  /opt/aldccp/bin/packages_idx -p %{name} -v %{version} $RPM_BUILD_ROOT
fi
%endif

# ------------------- Clean ------------------------------------------
%Clean 

DE=%{version}-%{release}.%{TO_ARCH}.rpm
DD=%{_rpmdir}/%{TO_ARCH}/%{ALD_Ver}%{DestDir}
DEC=%{version}-%{release}.%{_build_cpu}.rpm
DDC=%{_rpmdir}/%{_build_cpu}/%{ALD_Ver}%{CrossDestDir}/%{TO_ARCH}%{DestDir}

pushd %{_rpmdir}/%{_target_cpu}
  SE=%{version}-%{release}.%{_target_cpu}.rpm
%if (%{_os} == "mingw")
  rm %{name}-$SE
%if %{BUILD_LOCAL_CROSS}
  mkdir -p $DDC
  mv %{name}-%{TO_ARCH}-$SE $DDC/%{name}-%{TO_ARCH}-$DEC
%endif #BUILD_LOCAL_CROSS
%else  #mingw
  mkdir -p $DD
  mv %{name}-$SE $DD/%{name}-$DE
  mv %{name}-devel-$SE $DD/%{name}-devel-$DE
  mv %{name}-devel-man-$SE $DD/%{name}-devel-man-$DE
  mv %{name}-staticlib-$SE $DD/%{name}-staticlib-$DE
  mv %{name}-uuidd-$SE $DD/%{name}-uuidd-$DE
  mv %{name}-info-$SE $DD/%{name}-info-$DE
%if %{BUILD_LOCAL_CROSS}
  mkdir -p $DDC
  mv %{name}-%{TO_ARCH}-$SE $DDC/%{name}-%{TO_ARCH}-$DEC
  mv %{name}-%{TO_ARCH}-staticlib-$SE $DDC/%{name}-%{TO_ARCH}-staticlib-$DEC
%endif #BUILD_LOCAL_CROSS
%endif #!mingw
popd

# --------------- build *.tgz ------------------------
%if %{BUILD_TAR}
pushd $RPM_BUILD_ROOT
%if (%{_os} == "mingw")
  TMP_TO=$DD
%else
  TMP_TO=$DD/tar
%endif
  mkdir -p $TMP_TO
  tmp=%{name}-%{version}-%{release}.%{TO_ARCH}
  mkdir -p $tmp
  cp -r etc %{_lib} sbin usr var $tmp/
%if (%{_os} == "mingw")
  zip -9 -r $tmp.zip $tmp >/dev/null
  mv $tmp.zip $TMP_TO
%else
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
%endif
  rm -r $tmp
%if %{BUILD_LOCAL_CROSS}
  TMP_TO=$DDC/tar
  mkdir -p $TMP_TO
  tmp=%{name}-%{TO_ARCH}-%{version}-%{release}.%{_build_cpu}
  mkdir -p $tmp
  cp -r cross $tmp/
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
  rm -r $tmp
%endif
popd
%endif  #BUILD_TAR

# ------------------- Files ------------------------------------------
%if %{_os} == "mingw"
%Files
%{_prefix}

%if %{BUILD_LOCAL_CROSS}
%Files %{TO_ARCH}
%{csysdir}
%endif #!BUILD_LOCAL_CROSS
%else  #mingw

%files
/etc
/%{_lib}
/sbin
%{_bindir}/chattr
%{_bindir}/lsattr
%{_bindir}/uuidgen
%exclude %{_sbindir}/uuidd
%{_sbindir}
%{_mandir}/man1/chattr.1*
%{_mandir}/man1/lsattr.1*
%{_mandir}/man1/uuidgen.1*
%{_mandir}/man5
%exclude %{_mandir}/man8/uuidd.8.gz
%{_mandir}/man8
%{docdir}

%files devel
%{_bindir}/compile_et
%{_bindir}/mk_cmds
%{_libdir}/*.so
%{_libdir}/pkgconfig
%{_includedir}
%{_datadir}/et
%{_datadir}/ss

%Files devel-man
%{_mandir}/man1/compile_et.1*
%{_mandir}/man1/mk_cmds.1*
%{_mandir}/man3

%files staticlib
%{_libdir}/*.a

%files info
%{_infodir}

%files uuidd
%{_mandir}/man8/uuidd.8*
%attr(6755, uuidd, uuidd) %{_sbindir}/uuidd
%dir %attr(2775, uuidd, uuidd) /var/lib/libuuid

%if %{BUILD_LOCAL_CROSS}

%files %{TO_ARCH}
%{csysdir}/%{_lib}
%{cross_libdir}/*.so
%{cross_libdir}/pkgconfig
%{cross_includedir}
%{cross_docdir}

%files %{TO_ARCH}-staticlib
%{cross_libdir}/*.a

%endif #!BUILD_LOCAL_CROSS
%endif #!mingw
